@@ -110,7 +110,7 @@
       if (function_exists('check_sm_version'))
          return check_sm_version($a, $b, $c);
 
-      if (is_defined('SM_VERSION'))
+      if (defined('SM_VERSION'))
          $version = SM_VERSION;
       else
          global $version;
@@ -229,7 +229,8 @@
 
          if ($count == 0)
          {
-            eval('if (compatibility_check_sm_version(' . $csv_version_string . ')) return;');
+            if (eval('if (compatibility_check_sm_version(' . $csv_version_string . ')) return TRUE; else return FALSE;'))
+               return;
             $last_csv_version_string = $csv_version_string;
             $last_version_string = $version_string;
             continue;
@@ -630,15 +631,13 @@ function load_config($plugin_name, $config_files, $return_errors=FALSE)
 
       if ($return_errors) return FALSE;
 
-      bindtextdomain('compatibility', $compatibility_sm_path . 'locale');
-      textdomain('compatibility');
+      sq_change_text_domain('compatibility');
       $error_msg = _("Administrative error:") . '<br />' 
                  . sprintf(_("The plugin %s has not been set up correctly."),
                            '&quot;<strong>' . $plugin_name . '</strong>&quot;') 
                  . '<br />' 
                  . _("Please read the README or INSTALL files that came with the plugin.");
-      bindtextdomain('squirrelmail', $compatibility_sm_path . 'locale');
-      textdomain('squirrelmail');
+      sq_change_text_domain('squirrelmail');
       include_once($compatibility_sm_path . 'functions/display_messages.php');
       global $color;
       plain_error_message($error_msg, $color);
@@ -717,16 +716,14 @@ function check_plugin_setup($pluginName, $configFiles, $return_errors=FALSE)
 
          //if ($return_errors) return FALSE;
 
-         bindtextdomain('compatibility', $compatibility_sm_path . 'locale');
-         textdomain('compatibility');
+         sq_change_text_domain('compatibility');
 
          if ($return_errors) 
          {
             $error_msg = sprintf(_("The file %s is missing from plugin %s."), 
                                  '&quot;<strong>' . $configFile . '</strong>&quot;',
                                  '&quot;<strong>' . $pluginName . '</strong>&quot;');
-            bindtextdomain('squirrelmail', $compatibility_sm_path . 'locale');
-            textdomain('squirrelmail');
+            sq_change_text_domain('squirrelmail');
             return $error_msg;
          }
 
@@ -738,8 +735,7 @@ function check_plugin_setup($pluginName, $configFiles, $return_errors=FALSE)
                               '&quot;<strong>' . $configFile . '</strong>&quot;') 
                     . '<br />'
                     . _("Please read the README or INSTALL files that came with the plugin.");
-         bindtextdomain('squirrelmail', $compatibility_sm_path . 'locale');
-         textdomain('squirrelmail');
+         sq_change_text_domain('squirrelmail');
          include_once($compatibility_sm_path . 'functions/display_messages.php');
          global $color;
          plain_error_message($error_msg, $color);
